@@ -25,7 +25,6 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <string.h>
 
 #ifdef VINAGRE_ENABLE_AVAHI
@@ -40,7 +39,7 @@
 #include "vinagre-plugin.h"
 
 typedef struct {
-  GladeXML  *xml;
+  GtkBuilder *xml;
   GtkWidget *dialog;
   GtkWidget *protocol_combo;
   GtkWidget *protocol_description_label;
@@ -77,7 +76,7 @@ static void
 protocol_combo_changed (GtkComboBox *combo, VinagreConnectDialog *dialog)
 {
   GtkTreeIter tree_iter;
-  gchar       *description, *label, *service;
+  gchar       *description, *service;
   GtkWidget   *options;
   GList       *children, *l;
 
@@ -93,9 +92,8 @@ protocol_combo_changed (GtkComboBox *combo, VinagreConnectDialog *dialog)
 		      PROTOCOL_OPTIONS, &options,
 		      -1);
 
-  label = g_strdup_printf ("<i><small>%s</small></i>", description);
-  gtk_label_set_markup (GTK_LABEL (dialog->protocol_description_label),
-			label);
+  gtk_label_set_label (GTK_LABEL (dialog->protocol_description_label),
+		       description);
 
 #ifdef VINAGRE_ENABLE_AVAHI
   if (service)
@@ -112,13 +110,11 @@ protocol_combo_changed (GtkComboBox *combo, VinagreConnectDialog *dialog)
   if (options)
     {
       gtk_box_pack_start (GTK_BOX (dialog->plugin_box), options, TRUE, TRUE, 0);
-      g_object_unref (options);
-      gtk_widget_show (dialog->plugin_box);
+      gtk_widget_show_all (dialog->plugin_box);
     }
   else
     gtk_widget_hide (dialog->plugin_box);
 
-  g_free (label);
   g_free (description);
   g_free (service);
 }
@@ -166,7 +162,8 @@ setup_protocol (VinagreConnectDialog *dialog)
         selected = i;
 
       g_strfreev (description);
-      g_object_unref (widget);
+      if (widget)
+	g_object_unref (widget);
       i++;
     }
 
@@ -366,16 +363,17 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
   gint                  result;
   VinagreConnectDialog  dialog;
 
-  dialog.xml = glade_xml_new (vinagre_utils_get_glade_filename (), "connect_dialog", NULL);
-  dialog.dialog = glade_xml_get_widget (dialog.xml, "connect_dialog");
+  dialog.xml = vinagre_utils_get_builder ();
+
+  dialog.dialog = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "connect_dialog"));
   gtk_window_set_transient_for (GTK_WINDOW (dialog.dialog), GTK_WINDOW (window));
 
-  dialog.protocol_combo = glade_xml_get_widget (dialog.xml, "protocol_combo");
-  dialog.protocol_description_label = glade_xml_get_widget (dialog.xml, "protocol_description_label");
-  dialog.host_entry  = glade_xml_get_widget (dialog.xml, "host_entry");
-  dialog.find_button = glade_xml_get_widget (dialog.xml, "find_button");
-  dialog.fullscreen_check = glade_xml_get_widget (dialog.xml, "fullscreen_check");
-  dialog.plugin_box = glade_xml_get_widget (dialog.xml, "plugin_options_vbox");
+  dialog.protocol_combo = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "protocol_combo"));
+  dialog.protocol_description_label = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "protocol_description_label"));
+  dialog.host_entry  = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "host_entry"));
+  dialog.find_button = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "find_button"));
+  dialog.fullscreen_check = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "fullscreen_check"));
+  dialog.plugin_box = GTK_WIDGET (gtk_builder_get_object (dialog.xml, "plugin_options_connect_vbox"));
 
   setup_protocol (&dialog);
   setup_combo (dialog.host_entry);
@@ -425,7 +423,12 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
       g_free (protocol);
 
       conn = vinagre_plugin_new_connection (plugin);
-      if (vinagre_connection_split_string (host, &protocol, &actual_host, &port, &error_msg))
+      if (vinagre_connection_split_string (host,
+					   vinagre_connection_get_protocol (conn),
+					   &protocol,
+					   &actual_host,
+					   &port,
+					   &error_msg))
 	{
 	  g_object_set (conn,
 			"host", actual_host,
@@ -433,7 +436,8 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
 			"fullscreen", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog.fullscreen_check)),
 			NULL);
 
-	  vinagre_connection_parse_options_widget (conn, options);
+	  if (options)
+	    vinagre_connection_parse_options_widget (conn, options);
 
 	  g_free (protocol);
 	  g_free (actual_host);
@@ -445,7 +449,8 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
 	}
 
       g_object_unref (plugin);
-      g_object_unref (options);
+      if (options)
+	g_object_unref (options);
 
 fail:
       g_free (host);
